/* Welcome to DmxSimple. This library allows you to control DMX stage and
** architectural lighting and visual effects easily from Arduino. DmxSimple
** is compatible with the Tinker.it! DMX shield and all known DIY Arduino
** DMX control circuits.
**
** DmxSimple is available from: http://code.google.com/p/tinkerit/
** Help and support: http://groups.google.com/group/dmxsimple       */

/* To use DmxSimple, you will need the following line. Arduino will
** auto-insert it if you select Sketch > Import Library > DmxSimple. */

#include <DmxSimple.h>

#include <SPI.h>

//Add the SdFat Libraries
#include <SdFat.h>
#include <SdFatUtil.h> 

//and the MP3 Shield Library
#include <SFEMP3Shield.h>

//create and name the library object
SFEMP3Shield MP3player;

long trigger;

void setup() {
  /* The most common pin for DMX output is pin 3, which DmxSimple
  ** uses by default. If you need to change that, do it here. */
  DmxSimple.usePin(14);

  /* DMX devices typically need to receive a complete set of channels
  ** even if you only need to adjust the first channel. You can
  ** easily change the number of channels sent here. If you don't
  ** do this, DmxSimple will set the maximum channel number to the
  ** highest channel you DmxSimple.write() to. */
  DmxSimple.maxChannel(25);
  
  pinMode(15, OUTPUT);
 
  MP3player.begin();
  
  pinMode(19, OUTPUT);
  pinMode(18, INPUT);
   
  digitalWrite(15, HIGH);
  
  Serial.begin(9600);
  
  //read sensor once at first
  trigger = getRange();
  //set trigger threshold just shorther,
  if (trigger == 0) 
    trigger = 36;
  else 
    trigger -= 4;
  
  Serial.println(trigger);
}

void loop() {
  //leave light dim blue for all clear
  DmxSimple.write(3,1);
  //read sensor
  long range = getRange();
  Serial.println(range);
  if(range < trigger && range > 0){
    //warn the actor by turning off dim blue light
    DmxSimple.write(3,0);
    //wait for it
    delay(2000);
    //play sound effect and strobe light!
    MP3player.playTrack(10);
    for(int i=0; i<40; i++){
      DmxSimple.write(1,255);
      delay(50);
      DmxSimple.write(1,0);
      delay(50);
    }
    delay(5000);
  }
  delay(150);
}

long microsecondsToInches(long microseconds)
{
  // According to Parallax's datasheet for the PING))), there are
  // 73.746 microseconds per inch (i.e. sound travels at 1130 feet per
  // second).  This gives the distance travelled by the ping, outbound
  // and return, so we divide by 2 to get the distance of the obstacle.
  // See: http://www.parallax.com/dl/docs/prod/acc/28015-PING-v1.3.pdf
  return microseconds / 74 / 2;
}

long getRange(){
  
  digitalWrite(19, LOW);
  delayMicroseconds(2);
  digitalWrite(19, HIGH);
  delayMicroseconds(5);
  digitalWrite(19, LOW);
  
  long duration = pulseIn(18, HIGH, 44400);

  // convert the time into a distance
  long inches = microsecondsToInches(duration);
  
  return inches;
  
}
